
extendedSelling = {}
function extendedSelling.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(Washable, specializations) and SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations)
end
function extendedSelling.registerEventListeners(vehicleType)
	for _, functionName in pairs( { "onLoad", "onLoadFinished" } ) do
		SpecializationUtil.registerEventListener(vehicleType, functionName, extendedSelling)
	end
end
function extendedSelling.registerFunctions(vehicleType)
	SpecializationUtil.registerFunction(vehicleType, "eoiminuteChanged", extendedSelling.eoiminuteChanged)
	SpecializationUtil.registerFunction(vehicleType, "eoihourChanged", extendedSelling.eoihourChanged)
end
function extendedSelling.registerOverwrittenFunctions(vehicleType)
	SpecializationUtil.registerOverwrittenFunction(vehicleType, "getSellPrice", extendedSelling.getSellPrice)
	SpecializationUtil.registerOverwrittenFunction(vehicleType, "getSellPrice_RVBClone", extendedSelling.getSellPrice_RVBClone)
end
function extendedSelling:onLoad(savegame)
	self.ownedItemsProfitLoss = {}
	--g_messageCenter:subscribe(MessageType.MINUTE_CHANGED, extendedSelling.eoiminuteChanged, self)
	g_messageCenter:subscribe(MessageType.HOUR_CHANGED, extendedSelling.eoihourChanged, self)
	if g_modIsLoaded["FS25_gameplay_Real_Vehicle_Breakdowns"] then
		FS25_gameplay_Real_Vehicle_Breakdowns.rvbWorkshopScreen.setVehicleDetails = Utils.appendedFunction(FS25_gameplay_Real_Vehicle_Breakdowns.rvbWorkshopScreen.setVehicleDetails, extendedSelling.rvbWorkshopScreen_setVehicleDetails)
	end
end
function extendedSelling:onLoadFinished(savegame)
	self.ownedItemsProfitLoss.plus_minus = math.random(0, 99)
	self.ownedItemsProfitLoss.percentage = math.random(2, 25)
end
function extendedSelling:eoiminuteChanged()
	self.ownedItemsProfitLoss.plus_minus = math.random(0, 99)
	self.ownedItemsProfitLoss.percentage = math.random(2, 25)
	g_workshopScreen.list:reloadData()
	g_inGameMenu.pageStatistics:updateVehicles()
end
function extendedSelling:eoihourChanged()
	if g_currentMission.environment.currentHour < 19 and g_currentMission.environment.currentHour > 7 then
		self.ownedItemsProfitLoss.plus_minus = math.random(0, 99)
		self.ownedItemsProfitLoss.percentage = math.random(2, 25)
		g_workshopScreen.list:reloadData()
		g_inGameMenu.pageStatistics:updateVehicles()
		if (self.ownedItemsProfitLoss.plus_minus % 2 == 0) and self.ownedItemsProfitLoss.percentage > 20 and self.propertyState == VehiclePropertyState.OWNED then
			local message = string.format(g_i18n:getText("demandIncrease"), self:getFullName(), self.ownedItemsProfitLoss.percentage)
			g_currentMission.hud:addSideNotification(FSBaseMission.INGAME_NOTIFICATION_OK, message, 10000, GuiSoundPlayer.SOUND_SAMPLES.SUCCESS)
		end
	end
end
function extendedSelling:getSellPrice(superFunc)
	local sellPrice = superFunc(self)
	if g_currentMission.environment.currentHour < 19 and g_currentMission.environment.currentHour > 7 then
		local eoiamount = (sellPrice / 100) * self.ownedItemsProfitLoss.percentage
		local PL_price = 0
		if self.ownedItemsProfitLoss.plus_minus <= 33 then
			PL_price = sellPrice
		elseif self.ownedItemsProfitLoss.plus_minus <= 66 then
			if (self.ownedItemsProfitLoss.plus_minus % 2 == 0) then
				PL_price = sellPrice + eoiamount
			else
				PL_price = sellPrice - eoiamount
			end
		else
			if (self.ownedItemsProfitLoss.plus_minus % 2 == 0) then
				PL_price = sellPrice + eoiamount
			else
				PL_price = sellPrice - eoiamount
			end
		end
		return PL_price
	else
		return sellPrice
	end
end
function extendedSelling:getSellPrice_RVBClone(superFunc)
	if g_modIsLoaded["FS25_gameplay_Real_Vehicle_Breakdowns"] then
		local storeItem = g_storeManager:getItemByXMLFilename(self.configFileName)
		local sellPrice = FS25_gameplay_Real_Vehicle_Breakdowns.VehicleBreakdowns.calculateSellPriceClone(storeItem, self.age, self.operatingTime, self:getPrice(), self:getRepairPrice(), self:getRepairPrice_RVBClone(), self:getRepaintPrice())
		if g_currentMission.environment.currentHour < 19 and g_currentMission.environment.currentHour > 7 then
			local eoiamount = (sellPrice / 100) * self.ownedItemsProfitLoss.percentage
			local PL_price = 0
			if self.ownedItemsProfitLoss.plus_minus <= 33 then
				PL_price = sellPrice
			elseif self.ownedItemsProfitLoss.plus_minus <= 66 then
				if (self.ownedItemsProfitLoss.plus_minus % 2 == 0) then
					PL_price = sellPrice + eoiamount
				else
					PL_price = sellPrice - eoiamount
				end
			else
				if (self.ownedItemsProfitLoss.plus_minus % 2 == 0) then
					PL_price = sellPrice + eoiamount
				else
					PL_price = sellPrice - eoiamount
				end
			end
			return PL_price
		else
			return sellPrice
		end
	end
end
function extendedSelling.WorkshopScreen_setVehicleDetails(p74, p75, p76)
	local v77, v78
	if p75 == nil then
		v77 = 0
		v78 = 0
	else
		v77 = p75:getOperatingTime()
		v78 = p75.age
		if p75.propertyState == VehiclePropertyState.OWNED then
			local v79 = p75:getSellPrice() * EconomyManager.DIRECT_SELL_MULTIPLIER
			local v80 = math.floor(v79)
			local v81 = math.min(v80, p75:getPrice())
			--p76:getAttribute("priceText"):setText(g_i18n:formatMoney(v81))
			if g_currentMission.environment.currentHour < 19 and g_currentMission.environment.currentHour > 7 then
				local priceStr = "-"
				if (p75.ownedItemsProfitLoss.plus_minus % 2 == 0) then
					priceStr = string.format("%s (+%d%%)", g_i18n:formatMoney(v81), p75.ownedItemsProfitLoss.percentage)
				else
					priceStr = string.format("%s (-%d%%)", g_i18n:formatMoney(v81), p75.ownedItemsProfitLoss.percentage)
				end
				p76:getAttribute("priceText"):setText(priceStr)
			else
				p76:getAttribute("priceText"):setText(g_i18n:formatMoney(v81))
			end
		end
	end
end
WorkshopScreen.setVehicleDetails = Utils.appendedFunction(WorkshopScreen.setVehicleDetails, extendedSelling.WorkshopScreen_setVehicleDetails)
function extendedSelling.rvbWorkshopScreen_setVehicleDetails(p74, p75, p76)
	local v77, v78
	local rvb = p75.spec_faultData
	if p75 == nil then
		v77 = 0
		v78 = 0
	else
		v77 = p75:getOperatingTime()
		v78 = p75.age
		if p75.propertyState == VehiclePropertyState.OWNED then
			local v79 = p75:getSellPrice() * EconomyManager.DIRECT_SELL_MULTIPLIER
			local v80 = math.floor(v79)
			local v81 = math.min(v80, p75:getPrice())
			--p76:getAttribute("priceText"):setText(g_i18n:formatMoney(v81))
			if g_currentMission.environment.currentHour < 19 and g_currentMission.environment.currentHour > 7 then
				local priceStr = "-"
				if (p75.ownedItemsProfitLoss.plus_minus % 2 == 0) then
					priceStr = string.format("%s (+%d%%)", g_i18n:formatMoney(v81), p75.ownedItemsProfitLoss.percentage)
				else
					priceStr = string.format("%s (-%d%%)", g_i18n:formatMoney(v81), p75.ownedItemsProfitLoss.percentage)
				end
				p76:getAttribute("priceText"):setText(priceStr)
			else
				p76:getAttribute("priceText"):setText(g_i18n:formatMoney(v81))
			end	
		end
	end
end
function extendedSelling.InGameMenuStatisticsFrame_updateVehicles(p76)
	p76.vehicles = {}
	if g_localPlayer ~= nil then
		local v77 = g_currentMission
		local v78 = v77.accessHandler
		for _, v79 in ipairs(v77.vehicleSystem.vehicles) do
			if v78:canPlayerAccess(v79) and (v79:getShowInVehiclesOverview() and g_localPlayer.farmId == v79:getOwnerFarmId()) then
				local v80 = {
					["vehicle"] = v79,
					["columns"] = {}
				}
				local v81 = v79:getFullName()
				v80.columns[InGameMenuStatisticsFrame.COLUMN_NAME] = {
					["text"] = v81,
					["value"] = v81
				}
				local v82 = {
					["text"] = Vehicle.getSpecValueAge(nil, v79),
					["value"] = v79.age
				}
				v80.columns[InGameMenuStatisticsFrame.COLUMN_AGE] = v82
				local v83, v84
				if v79.getOperatingTime == nil then
					v83 = "-"
					v84 = 0
				else
					v83 = Vehicle.getSpecValueOperatingTime(nil, v79)
					v84 = v79:getOperatingTime()
				end
				v80.columns[InGameMenuStatisticsFrame.COLUMN_HOURS] = {
					["text"] = v83,
					["value"] = v84
				}
				local v85, v86
				if SpecializationUtil.hasSpecialization(Wearable, v79.specializations) then
					v85 = v79:getDamageAmount()
					local v87 = g_i18n
					local v88 = (1 - v85) * 100
					v86 = v87:formatNumber(math.ceil(v88), 0) .. " %"
				else
					v86 = "-"
					v85 = 0
				end
				v80.columns[InGameMenuStatisticsFrame.COLUMN_DAMAGE] = {
					["text"] = v86,
					["value"] = v85
				}
				local v89, v90
				if v79.propertyState == VehiclePropertyState.LEASED then
					v89 = v79.price * (EconomyManager.DEFAULT_RUNNING_LEASING_FACTOR + EconomyManager.PER_DAY_LEASING_FACTOR)
					v90 = g_i18n:formatMoney(v89)
				else
					v90 = "-"
					v89 = 0
				end
				v80.columns[InGameMenuStatisticsFrame.COLUMN_LEASING] = {
					["text"] = v90,
					["value"] = v89
				}
				local v91, v92
				if v79.propertyState == VehiclePropertyState.OWNED then
					--v91 = v79:getSellPrice()
					--v92 = g_i18n:formatMoney(v91)
					if g_currentMission.environment.currentHour < 19 and g_currentMission.environment.currentHour > 7 then
						local rvb = v79.spec_faultData
						if rvb ~= nil then
							v91 = v79:getSellPrice_RVBClone()
						else
							v91 = v79:getSellPrice()
						end
						if (v79.ownedItemsProfitLoss.plus_minus % 2 == 0) then
							v92 = string.format("%s (+%d%%)", g_i18n:formatMoney(v91, 0, true, true), v79.ownedItemsProfitLoss.percentage)
						else
							v92 = string.format("%s (-%d%%)", g_i18n:formatMoney(v91, 0, true, true), v79.ownedItemsProfitLoss.percentage)
						end
					else
						v91 = v79:getSellPrice()
						v92 = g_i18n:formatMoney(v91)
					end
				else
					v92 = "-"
					v91 = 0
				end
				v80.columns[InGameMenuStatisticsFrame.COLUMN_VALUE] = {
					["text"] = v92,
					["value"] = v91
				}
				local v93 = p76.vehicles
				table.insert(v93, v80)
			end
		end
	end
	p76:updateView()
end
InGameMenuStatisticsFrame.updateVehicles = Utils.overwrittenFunction(InGameMenuStatisticsFrame.updateVehicles, extendedSelling.InGameMenuStatisticsFrame_updateVehicles)